Increase the small thread stack size to get the test
to pass reliably on the one buildbot that insists on
more than 32kB of thread stack.
diff --git a/Lib/test/test_threading.py b/Lib/test/test_threading.py
index 02f338a..ac4a010 100644
--- a/Lib/test/test_threading.py
+++ b/Lib/test/test_threading.py
@@ -85,11 +85,11 @@
             print 'all tasks done'
         self.assertEqual(numrunning.get(), 0)
 
     # run with a minimum thread stack size (32kB)
     def test_various_ops_small_stack(self):
         if verbose:
-            print 'with 32kB thread stack size...'
-        threading.stack_size(0x8000)
+            print 'with 256kB thread stack size...'
+        threading.stack_size(262144)
         self.test_various_ops()
         threading.stack_size(0)
@@ -85,11 +85,11 @@
         self.assertEqual(numrunning.get(), 0)
 
-    # run with a minimum thread stack size (32kB)
+    # run with a small(ish) thread stack size (256kB)
     def test_various_ops_small_stack(self):
         if verbose: